@@ -13,10 +13,11 @@ import requests
 end_of_field = re.compile(r'\r\n\r\n|\r\r|\n\n')
 
 class SSEClient(object):
-    def __init__(self, url, last_id=None, retry=3000, session=None, **kwargs):
+    def __init__(self, url, last_id=None, retry=3000, session=None, chunk_size=1024, **kwargs):
         self.url = url
         self.last_id = last_id
         self.retry = retry
+        self.chunk_size = chunk_size
 
         # Optional support for passing in a requests.Session()
         self.session = session
@@ -44,7 +45,7 @@ class SSEClient(object):
         # Use session if set.  Otherwise fall back to requests module.
         requester = self.session or requests
         self.resp = requester.get(self.url, stream=True, **self.requests_kwargs)
-        self.resp_file = self.resp.raw
+        self.resp_iterator = self.resp.iter_content(chunk_size=self.chunk_size)
 
         # TODO: Ensure we're handling redirects.  Might also stick the 'origin'
         # attribute on Events like the Javascript spec requires.
@@ -61,10 +62,11 @@ class SSEClient(object):
             self.resp.encoding)(errors='replace')
         while not self._event_complete():
             try:
-                nextline = self.resp_file.readline()
-                if not nextline:
+                next_chunk = next(self.resp_iterator)
+                if not next_chunk:
                     raise EOFError()
-                self.buf += decoder.decode(nextline)
+                self.buf += decoder.decode(next_chunk)
+
             except (StopIteration, requests.RequestException, EOFError) as e:
                 time.sleep(self.retry / 1000.0)
                 self._connect()
@@ -75,12 +77,11 @@ class SSEClient(object):
                 self.buf = head + sep
                 continue
 
-        split = re.split(end_of_field, self.buf)
-        head = split[0]
-        tail = "".join(split[1:])
-
-        self.buf = tail
-        msg = Event.parse(head)
+        # Split the complete event (up to the end_of_field) into event_string,
+        # and retain anything after the current complete event in self.buf
+        # for next time.
+        (event_string, self.buf) = re.split(end_of_field, self.buf, maxsplit=1)
+        msg = Event.parse(event_string)
 
         # If the server requests a specific retry delay, we need to honor it.
         if msg.retry:
@@ -129,18 +130,18 @@ class Event(object):
         and return a Event object.
         """
         msg = cls()
-        for line in raw.split('\n'):
+        for line in raw.splitlines():
             m = cls.sse_line_pattern.match(line)
             if m is None:
                 # Malformed line.  Discard but warn.
                 warnings.warn('Invalid SSE line: "%s"' % line, SyntaxWarning)
                 continue
 
-            name = m.groupdict()['name']
-            value = m.groupdict()['value']
+            name = m.group('name')
             if name == '':
                 # line began with a ":", so is a comment.  Ignore
                 continue
+            value = m.group('value')
 
             if name == 'data':
                 # If we already have some data, then join to it with a newline.
